@@ -35,10 +35,16 @@ class Learning(object):
                             self.cache[new_word] = 1
                     del tmp
                     tmp = []
+            new_word = ''.join(tmp)
+            if new_word:
+                if new_word in self.cache:
+                    self.cache[new_word] += 1
+                else:
+                    self.cache[new_word] = 1
             if count%1000 == 0:
                 print("count:%d" % count)
     def save(self,path):
         with open(path,'w') as f:
             for word in self.cache.viewitems():
                 if word[1]>=self.times:
-                    f.write(word[0].encode("utf-8")+'\n')
+                    f.write('%s\t%s\n' % (word[0].encode("utf-8"),word[1]))
